import math

# dy/dt = -0.002y
# initial y = 0.02
# calculate y at t = 60
# use a time step of 60 as well



#############
# analytical
#############

print('##################')
print('ANALYTICAL')
print('##################')

y = 0.02 * math.exp(60.0 * -0.002)
print('analytical solution', y)                 # 0.0177384087343 


#############
# Euler-Cauchy
#############

print('##################')
print('EULER-CAUCHY')
print('##################')

k = -0.002
dt = 60.0

y = 0.02

changePerT = k * y                                # -0.002 * 0.02
print('change over the time step ', changePerT)   # 0.00004

yNext = y + dt * changePerT                       # 0.02 * 60 * 0.00004
print('y at next timestep', yNext)                # 0.0176


#############
# Heun 
#############

print('##################')
print('HEUN')
print('##################')

k = -0.002
dt = 60.0

y = 0.02

changePerT = k * y                                     # -0.002 * 0.02
print('change over the time step, Heun ', changePerT)  # -0.00004

yNextHeun = y + dt * changePerT                        # 0.02 * 60 * 0.00004
print('y at next timestep Heun', yNextHeun)            # 0.0176

changePerTFromYNextHeun = k * yNextHeun                # -0.002 * 0.0176
print('change over the time step from y next Heun ', changePerTFromYNextHeun)
                                                       # -0.0000352

yNext = y + dt * ((changePerT+changePerTFromYNextHeun)/2.0)
                                                       # 0.02 + 60 * (-0.00004 - 0.0000352) / 2.0
print('y at next timestep, Heun', yNext)               # 0.017744


#############
# Runge-Kutta 
#############

print('##################')
print('Runge-Kutta')
print('##################')

k = -0.002
dt = 60.0

y = 0.02

kOne = dt * k * y
print('kOne', kOne)

kTwo = dt * k * (y + 0.5 * kOne)
print('kTwo', kTwo)

kThree = dt * k * (y + 0.5 * kTwo)
print('kThree', kThree)

kFour = dt * k * (y + kThree)
print('kFour', kFour)

yNext= y + (1.0/6.0)*(kOne + 2.0 * kTwo + 2.0 * kThree + kFour)
print('y at next timestep, Runge-Kutta', yNext)
